SQLAlchemy 0.4 Documentation - module sqlalchemy.types

# SQLAlchemy 0.4 Documentation

Multiple Pages | One Page
Version: 0.4 Last Updated: 08/16/07 11:15:18

### module sqlalchemy.types

### class BLOB(Binary)

back to section top

### class BOOLEAN(Boolean)

back to section top

### class Binary(TypeEngine)

def __init__(self, length=None)

Construct a new `Binary`.

def adapt(self, impltype)
def bind_processor(self, dialect)
def get_dbapi_type(self, dbapi)
back to section top

### class Boolean(TypeEngine)

back to section top

### class CHAR(String)

back to section top

### class CLOB(TEXT)

back to section top

### class DATE(Date)

back to section top

### class DATETIME(DateTime)

back to section top

### class DECIMAL(Numeric)

back to section top

### class Date(TypeEngine)

Implement a type for `datetime.date()` objects.

def get_dbapi_type(self, dbapi)
back to section top

### class DateTime(TypeEngine)

Implement a type for `datetime.datetime()` objects.

def __init__(self, timezone=False)

Construct a new `DateTime`.

def adapt(self, impltype)
def get_dbapi_type(self, dbapi)
back to section top

### class FLOAT(Float)

back to section top

### class Float(Numeric)

def __init__(self, precision=10, asdecimal=False, **kwargs)

Construct a new `Float`.

def adapt(self, impltype)
back to section top

### class INT(Integer)

back to section top

### class Integer(TypeEngine)

Integer datatype.

def get_dbapi_type(self, dbapi)
back to section top

### class Interval(TypeDecorator)

Type to be used in Column statements to store python timedeltas.

If it's possible it uses native engine features to store timedeltas (now it's only PostgreSQL Interval type), if there is no such it fallbacks to DateTime storage with converting from/to timedelta on the fly

Converting is very simple - just use epoch(zero timestamp, 01.01.1970) as base, so if we need to store timedelta = 1 day (24 hours) in database it will be stored as DateTime = '2nd Jan 1970 00:00', see bind_processor and result_processor to actual conversion code

def bind_processor(self, dialect)
def load_dialect_impl(self, dialect)

Checks if engine has native implementation of timedelta python type, if so it returns right class to handle it, if there is no native support, it fallback to engine's DateTime implementation class

def result_processor(self, dialect)
back to section top

### class NCHAR(Unicode)

back to section top

### class NullType(TypeEngine)

def get_col_spec(self)
back to section top

### class Numeric(TypeEngine)

def __init__(self, precision=10, length=2, asdecimal=True)

Construct a new `Numeric`.

def adapt(self, impltype)
def bind_processor(self, dialect)
def get_dbapi_type(self, dbapi)
def result_processor(self, dialect)
back to section top

### class PickleType(MutableType,TypeDecorator)

def __init__(self, protocol=2, pickler=None, mutable=True)

Construct a new `PickleType`.

def bind_processor(self, dialect)
def compare_values(self, x, y)
def copy_value(self, value)
def is_mutable(self)
def result_processor(self, dialect)
back to section top

### class SMALLINT(SmallInteger)

back to section top

### class SmallInteger(Integer)

Smallint datatype.

back to section top

### class String(TypeEngine,Concatenable)

def __init__(self, length=None, convert_unicode=False)

Construct a new `String`.

def adapt(self, impltype)
def bind_processor(self, dialect)
def get_dbapi_type(self, dbapi)
def get_search_list(self)
def result_processor(self, dialect)
back to section top

### class TEXT(String)

back to section top

### class TIME(Time)

back to section top

### class TIMESTAMP(DateTime)

back to section top

### class Time(TypeEngine)

Implement a type for `datetime.time()` objects.

def __init__(self, timezone=False)

Construct a new `Time`.

def adapt(self, impltype)
def get_dbapi_type(self, dbapi)
back to section top

### class TypeDecorator(AbstractType)

def __init__(self, *args, **kwargs)

Construct a new `TypeDecorator`.

def bind_processor(self, dialect)
def compare_values(self, x, y)
def copy(self)
def copy_value(self, value)
def dialect_impl(self, dialect)
def get_col_spec(self)
def get_dbapi_type(self, dbapi)
def is_mutable(self)
def load_dialect_impl(self, dialect)

loads the dialect-specific implementation of this type.

by default calls dialect.type_descriptor(self.impl), but can be overridden to provide different behavior.

def result_processor(self, dialect)
def __getattr__(self, key)

Proxy all other undefined accessors to the underlying implementation.

back to section top

### class TypeEngine(AbstractType)

def adapt(self, cls)
def bind_processor(self, dialect)
def dialect_impl(self, dialect)
def get_col_spec(self)
def get_search_list(self)

return a list of classes to test for a match when adapting this type to a dialect-specific type.

def result_processor(self, dialect)
back to section top

### class Unicode(String)

def __init__(self, length=None, **kwargs)

Construct a new `Unicode`.

back to section top

### class VARCHAR(String)

back to section top